@@ -148,6 +148,7 @@ class Build(HeadersMixin):
     make_variables = attrib(default={})
     kernel_image = attrib(default=None)
     patch_series = attrib(default=None)
+    image_sha = attrib(default=None)
 
     build_data = attrib(default=None)
     build_name = attrib(default=None)
@@ -210,6 +211,8 @@ class Build(HeadersMixin):
             build_entry["build_name"] = self.build_name
         if plan is not None:
             build_entry["plan"] = plan
+        if self.image_sha:
+            build_entry["image_sha"] = self.image_sha
         if self.patch_series:
             (
                 build_entry["kernel_patch_file"],
@@ -307,6 +310,7 @@ class Build(HeadersMixin):
                 ):
                     attempts += 1
                     message = self.status.get("status_message", "infrastructure error")
+                    timeout = time.time() + build_state_timeout
                     yield BuildState(
                         build=self,
                         state=self.status["tuxbuild_status"],
