@@ -346,6 +346,11 @@ def common_options(required):
     ]
 
     options = [
+        option(
+            "--image-sha",
+            default=None,
+            help=("Pin the container image sha (64 hexadecimal digits)"),
+        ),
         option(
             "--limit", default=LIMIT, help="Limit to LIMIT output. Used with [list]"
         ),
